@@ -361,7 +361,7 @@ def env_create( en , ev ) :
     return(True)
 
 def env_count( ) :
-    count = table_count( "env" )
+    count = table_rowcount( "env" )
     return( count )
 
 def env_read( en ) :
@@ -441,7 +441,7 @@ def args_create( av ) :
     return(True)
 
 def args_count( ) :
-    count = table_count( "args" )
+    count = table_rowcount( "args" )
     return( count )
 
 def args_read( aid ) :
@@ -470,20 +470,29 @@ def args_deleteall( ) :
 
 ####################################################################
 
+# stdin 0 , stdout 1 , stderr 2
 def stdio_create( sk , sv ) :
     sql = "INSERT INTO stdio ( sid , sk , sv ) VALUES ( null , ? , ? )"
     data = ( sk , sv )
     sql_execute_parameters( sql , data )
     return( True )
 
-def stdio_count( ) :
-    count = table_count( "stdio" )
+def stdio_count( sk ) :
+    count = table_rowcount( "stdio" , "where sk=" + str( sk ) )
     return( count )
 
 def stdio_read( sk ) :
     sql = "SELECT * FROM stdio where sk=" + str( sk ) + " order by sid asc" 
     rows = sql_execute_fetchall( sql )
-    return( rows )    
+    return( rows )
+
+def stdio_readformatted( sk ) :
+    rows = stdio_read( sk )
+    buff = ""
+    for r in rows:
+        #buff = buff + str( r["sv"],"utf-8")+"\n"
+        buff = buff + r["sv"]+"\n"
+    return(buff)
 
 def stdio_readall( ) :
     rows = table_readall( "stdio" )
@@ -491,7 +500,7 @@ def stdio_readall( ) :
 
 def stdio_update( sid , sk , sv ) :
     sql = "UPDATE stdio SET sk=? , sv=? where sid=?"
-    data = ( sk,sv,sid )
+    data = ( sk , sv , sid )
     sql_execute_parameters( sql , data )
 
 def stdio_delete( sk = 0 ) :
@@ -504,6 +513,16 @@ def stdio_delete( sk = 0 ) :
 def stdio_deleteall( ) :
     table_truncate( "stdio" )
 
+def stdio_has_stderr( ) :
+
+    if( stdio_count( 2 ) > 0 ) :
+        return( True )
+
+    return( False )
+
+def stdio_get_stderr( ) :
+    return( stdio_readformatted( 2 ) )
+
 ####################################################################
 
 def files_create( fp ) :
@@ -535,10 +554,9 @@ def files_create( fp ) :
     return( True )
 
 def files_count( ) :
-    count = table_count( "files" )
+    count = table_rowcount( "files" )
     return( count )
 
-
 def files_read( fp ) :
 
     sql =  "SELECT * FROM files where fp='" + fp + "' limit 1" 
@@ -566,7 +584,6 @@ def files_delete( fp ) :
 def files_deleteall( ) :
     table_truncate( "files" )
 
-
 def files_dict2json( fp , fdict ) :
 
     if( s_util.pathnotallowed( fp ) ) : return( False )
@@ -582,18 +599,26 @@ def files_dict2json( fp , fdict ) :
 
     return( True )
 
+def files_get_defaultdata( ) :
+    f = files_read( "./local_sapiserver_default_5800b137d.json" )
+    if not f :
+        return( False )
+    d = json.loads( f[ "fc" ] )
+    return( d )
+
+
 
 ####################################################################
 
-def templates_create( tp,tk,tv ) :
+def templates_create( tp , tk , tv ) :
     if( s_util.pathnotallowed( tp ) ) : return( False )
     sql = "INSERT INTO templates ( tp,tk,tv) VALUES ( ? , ? , ? )"
-    data = ( tp,tk,tv )
+    data = ( tp , tk , tv )
     sql_execute_parameters( sql , data )
     return(True)
 
 def templates_count( ) :
-    count = table_count( "templates" )
+    count = table_rowcount( "templates" )
     return( count )
 
 def templates_read( tp ) :
@@ -605,9 +630,9 @@ def templates_readall( ) :
     rows = table_readall( "templates" )
     return( rows )    
 
-def templates_update( tp,tk,tv ) :
+def templates_update( tp , tk , tv ) :
     sql = "UPDATE templates SET tk=? , tv=? where tp=?"
-    data = ( tk,tv,tp )
+    data = ( tk , tv , tp )
     sql_execute_parameters( sql , data )
 
 def templates_delete( tp ) :
