@@ -14,6 +14,7 @@
 #####################################################################
 
 import os
+import sys
 import time
 import json
 import pickle
@@ -104,5 +105,8 @@ def is_ip( address ) :
 def uptime( ) :
     return( time.time( ) - s_config.get_key( "/config/init/time" ) )
 
+def printexit( msg ) :
+    print( msg )
+    sys.exit( )
 
 
