@@ -37,11 +37,24 @@ def ready( ) :
 
     return( True )
 
+def prexit( msg ) :
+    s_util.printexit( "FALSE tables" )
+
+def defout( ) :
+    return( s_db.files_get_defaultdata( ) )
+
+def uptime( ) :
+    return( s_util.uptime( ) )
+
 #####################################################################
 
 # DATA
 # TIMEOUT
-def express( meta_inputs = { } , wait_timeout = 30 ) :
+def express( meta_inputs = { } , wait_timeout = 60 ) :
+
+    if( not ready( ) ) :
+        s_log.write( "NOT READY" )
+        return( False )
 
     if( not meta_inputs ) :
         s_log.write( "false meta_inputs " )
@@ -89,4 +102,10 @@ def express( meta_inputs = { } , wait_timeout = 30 ) :
 
     #s_log.write(s_util.uptime())
 
+    if( s_db.stdio_has_stderr( ) ) :
+        s_log.write( s_db.stdio_get_stderr( ) )
+        return( None )
+
+    #####################################################################
+
     return( s_db.meta_read( "_" ) )
